@@ -23,7 +23,10 @@ def encrypt_aes(file_or_bytes_io, key, iv):
     key = base64.b64decode(key)
     iv = base64.b64decode(iv)
     aes = AES.new(key, AES.MODE_CBC, iv)
-    return aes.encrypt(pad(bytes(file_or_bytes_io.read(), encoding='iso-8859-1'), 16))
+    try:
+        return aes.encrypt(pad(bytes(file_or_bytes_io.read(), encoding='iso-8859-1'), 16))
+    except TypeError:
+        return aes.encrypt(pad(file_or_bytes_io.read(), 16))
 
 
 def decrypt_aes(content, key, iv):
